#include_next <stdlib.h>

#ifndef _STDLIB_H_
#define _STDLIB_H_

#include <bsd/stdlib.h>

#endif
